@@ -1,7 +1,7 @@
 import requests
 import time
 from yyweaknet.stf import STFServer
-from logger import get_logger
+from yyweaknet.logger import get_logger
 
 logger = get_logger(__name__)
 
@@ -173,3 +173,4 @@ if __name__ == '__main__':
     token = "24dc77b46c7542a28cc74888aed16d15fc0d0d3077ed48e5b68956e2668eef27"
     sft_url = "http://10.12.35.2:8086"
     config = WeakNetworkConfig("2834d69c9ee8c9c02280d7d8828697cde1920cd6", stf_url=sft_url, sft_token=token)
+    print(config)
